==> libreoffice-fresh-sdk-25.8.2-1-x86_64.pkg.tar.zst: usr/share/doc/libreoffice/sdk/docs/idl/ref/servicecom_1_1sun_1_1star_1_1presentation_1_1Shape.js <==
var servicecom_1_1sun_1_1star_1_1presentation_1_1Shape =
[
    [ "Bookmark", "servicecom_1_1sun_1_1star_1_1presentation_1_1Shape.html#a4a8f303623e170db1382649414edd504", null ],
    [ "DimColor", "servicecom_1_1sun_1_1star_1_1presentation_1_1Shape.html#ae8034b986c3925fbd489a062fc9c19de", null ],
    [ "DimHide", "servicecom_1_1sun_1_1star_1_1presentation_1_1Shape.html#a1a3471ac31f2bc9c4e3ecde12916ae81", null ],
    [ "DimPrevious", "servicecom_1_1sun_1_1star_1_1presentation_1_1Shape.html#a0dce913b03bab691e3b8bd53131d3bac", null ],
    [ "Effect", "servicecom_1_1sun_1_1star_1_1presentation_1_1Shape.html#a98f6e74b5a1350326d189bbf49bbbc33", null ],
    [ "IsEmptyPresentationObject", "servicecom_1_1sun_1_1star_1_1presentation_1_1Shape.html#ae6f3b9a9eef6c07bf91d6a4bfc5ddcce", null ],
    [ "IsPresentationObject", "servicecom_1_1sun_1_1star_1_1presentation_1_1Shape.html#a9b3421346e046fb240d583804e205729", null ],
    [ "OnClick", "servicecom_1_1sun_1_1star_1_1presentation_1_1Shape.html#a81fcffb31731a911184773e6ce1459c4", null ],
    [ "PlayFull", "servicecom_1_1sun_1_1star_1_1presentation_1_1Shape.html#a8f2e415d22db867805b55c7168e9ab25", null ],
    [ "PresentationOrder", "servicecom_1_1sun_1_1star_1_1presentation_1_1Shape.html#ab842908b6b449892efec2f0dd4343e40", null ],
    [ "Sound", "servicecom_1_1sun_1_1star_1_1presentation_1_1Shape.html#a69b174d1cbb65751c00b7779026c470f", null ],
    [ "SoundOn", "servicecom_1_1sun_1_1star_1_1presentation_1_1Shape.html#a728fa7de516702cb2c5444534deca638", null ],
    [ "Speed", "servicecom_1_1sun_1_1star_1_1presentation_1_1Shape.html#a971df36f052e927eeb4479778d650dd8", null ],
    [ "TextEffect", "servicecom_1_1sun_1_1star_1_1presentation_1_1Shape.html#a62754d721777add0417dd63b7e6a7a3d", null ],
    [ "Verb", "servicecom_1_1sun_1_1star_1_1presentation_1_1Shape.html#a94bb962b6e86fb13f374a374d0dec6ea", null ]
];

==> libreoffice-fresh-sdk-26.2.0-4-x86_64.pkg.tar.zst: usr/share/doc/libreoffice/sdk/docs/idl/ref/servicecom_1_1sun_1_1star_1_1presentation_1_1Shape.js <==
var servicecom_1_1sun_1_1star_1_1presentation_1_1Shape =
[
    [ "Bookmark", "servicecom_1_1sun_1_1star_1_1presentation_1_1Shape.html#a4a8f303623e170db1382649414edd504", null ],
    [ "CustomPromptText", "servicecom_1_1sun_1_1star_1_1presentation_1_1Shape.html#a03ff87c2aab7d446809eab1dc4c80ec2", null ],
    [ "DimColor", "servicecom_1_1sun_1_1star_1_1presentation_1_1Shape.html#ae8034b986c3925fbd489a062fc9c19de", null ],
    [ "DimHide", "servicecom_1_1sun_1_1star_1_1presentation_1_1Shape.html#a1a3471ac31f2bc9c4e3ecde12916ae81", null ],
    [ "DimPrevious", "servicecom_1_1sun_1_1star_1_1presentation_1_1Shape.html#a0dce913b03bab691e3b8bd53131d3bac", null ],
    [ "Effect", "servicecom_1_1sun_1_1star_1_1presentation_1_1Shape.html#a98f6e74b5a1350326d189bbf49bbbc33", null ],
    [ "IsEmptyPresentationObject", "servicecom_1_1sun_1_1star_1_1presentation_1_1Shape.html#ae6f3b9a9eef6c07bf91d6a4bfc5ddcce", null ],
    [ "IsPresentationObject", "servicecom_1_1sun_1_1star_1_1presentation_1_1Shape.html#a9b3421346e046fb240d583804e205729", null ],
    [ "OnClick", "servicecom_1_1sun_1_1star_1_1presentation_1_1Shape.html#a81fcffb31731a911184773e6ce1459c4", null ],
    [ "PlayFull", "servicecom_1_1sun_1_1star_1_1presentation_1_1Shape.html#a8f2e415d22db867805b55c7168e9ab25", null ],
    [ "PresentationOrder", "servicecom_1_1sun_1_1star_1_1presentation_1_1Shape.html#ab842908b6b449892efec2f0dd4343e40", null ],
    [ "Sound", "servicecom_1_1sun_1_1star_1_1presentation_1_1Shape.html#a69b174d1cbb65751c00b7779026c470f", null ],
    [ "SoundOn", "servicecom_1_1sun_1_1star_1_1presentation_1_1Shape.html#a728fa7de516702cb2c5444534deca638", null ],
    [ "Speed", "servicecom_1_1sun_1_1star_1_1presentation_1_1Shape.html#a971df36f052e927eeb4479778d650dd8", null ],
    [ "TextEffect", "servicecom_1_1sun_1_1star_1_1presentation_1_1Shape.html#a62754d721777add0417dd63b7e6a7a3d", null ],
    [ "Verb", "servicecom_1_1sun_1_1star_1_1presentation_1_1Shape.html#a94bb962b6e86fb13f374a374d0dec6ea", null ]
];
